Module version

Module version 

Structs

UpdateInfo
Response from the miuda.ai update-check endpoint.

Constants

SHORT_VERSION
VERSION_INFO

Functions

check_update
Query https://miuda.ai/api/check_update with current version + edition. Returns UpdateInfo on success.
get_short_version
get_useragent
get_version_info
spawn_update_checker
Spawn a background task that periodically checks for updates (at startup and every 24 hours). When a new version is found a system_notification row is inserted into the database (deduped by title so the same version only appears once).