Structs
- Update
Info - Response from the miuda.ai update-check endpoint.
Constants
Functions
- check_
update - Query
https://miuda.ai/api/check_updatewith current version + edition. ReturnsUpdateInfoon success. - get_
short_ version - get_
useragent - get_
version_ info - spawn_
update_ checker - Spawn a background task that periodically checks for updates (at startup and
every 24 hours). When a new version is found a
system_notificationrow is inserted into the database (deduped by title so the same version only appears once).