pub fn spawn_update_checker(db: DatabaseConnection, token: CancellationToken)Expand description
Spawn a background task that periodically checks for updates (at startup and
every 24 hours). When a new version is found a system_notification row is
inserted into the database (deduped by title so the same version only appears
once).